==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/VideoAnalyzerPresetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.VideoAnalyzerPresetArgs.builder
import com.pulumi.azurenative.media.kotlin.enums.AudioAnalysisMode
import com.pulumi.azurenative.media.kotlin.enums.InsightsType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A video analyzer preset that extracts insights (rich metadata) from both audio and video, and outputs a JSON format file.
 * @property audioLanguage The language for the audio payload in the input using the BCP-47 format of 'language tag-region' (e.g: 'en-US').  If you know the language of your content, it is recommended that you specify it. The language must be specified explicitly for AudioAnalysisMode::Basic, since automatic language detection is not included in basic mode. If the language isn't specified or set to null, automatic language detection will choose the first language detected and process with the selected language for the duration of the file. It does not currently support dynamically switching between languages after the first language is detected. The automatic detection works best with audio recordings with clearly discernable speech. If automatic detection fails to find the language, transcription would fallback to 'en-US'." The list of supported languages is available here: https://go.microsoft.com/fwlink/?linkid=2109463
 * @property experimentalOptions Dictionary containing key value pairs for parameters not exposed in the preset itself
 * @property insightsToExtract Defines the type of insights that you want the service to generate. The allowed values are 'AudioInsightsOnly', 'VideoInsightsOnly', and 'AllInsights'. The default is AllInsights. If you set this to AllInsights and the input is audio only, then only audio insights are generated. Similarly if the input is video only, then only video insights are generated. It is recommended that you not use AudioInsightsOnly if you expect some of your inputs to be video only; or use VideoInsightsOnly if you expect some of your inputs to be audio only. Your Jobs in such conditions would error out.
 * @property mode Determines the set of audio analysis operations to be performed. If unspecified, the Standard AudioAnalysisMode would be chosen.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.VideoAnalyzerPreset'.
 */
public data class VideoAnalyzerPresetArgs(
    public val audioLanguage: Output<String>? = null,
    public val experimentalOptions: Output<Map<String, String>>? = null,
    public val insightsToExtract: Output<Either<String, InsightsType>>? = null,
    public val mode: Output<Either<String, AudioAnalysisMode>>? = null,
    public val odataType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.VideoAnalyzerPresetArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.VideoAnalyzerPresetArgs =
        com.pulumi.azurenative.media.inputs.VideoAnalyzerPresetArgs.builder()
            .audioLanguage(audioLanguage?.applyValue({ args0 -> args0 }))
            .experimentalOptions(
                experimentalOptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .insightsToExtract(
                insightsToExtract?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .mode(
                mode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .odataType(odataType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VideoAnalyzerPresetArgs].
 */
@PulumiTagMarker
public class VideoAnalyzerPresetArgsBuilder internal constructor() {
    private var audioLanguage: Output<String>? = null

    private var experimentalOptions: Output<Map<String, String>>? = null

    private var insightsToExtract: Output<Either<String, InsightsType>>? = null

    private var mode: Output<Either<String, AudioAnalysisMode>>? = null

    private var odataType: Output<String>? = null

    /**
     * @param value The language for the audio payload in the input using the BCP-47 format of 'language tag-region' (e.g: 'en-US').  If you know the language of your content, it is recommended that you specify it. The language must be specified explicitly for AudioAnalysisMode::Basic, since automatic language detection is not included in basic mode. If the language isn't specified or set to null, automatic language detection will choose the first language detected and process with the selected language for the duration of the file. It does not currently support dynamically switching between languages after the first language is detected. The automatic detection works best with audio recordings with clearly discernable speech. If automatic detection fails to find the language, transcription would fallback to 'en-US'." The list of supported languages is available here: https://go.microsoft.com/fwlink/?linkid=2109463
     */
    @JvmName("faouvqlehvhjxlos")
    public suspend fun audioLanguage(`value`: Output<String>) {
        this.audioLanguage = value
    }

    /**
     * @param value Dictionary containing key value pairs for parameters not exposed in the preset itself
     */
    @JvmName("qodrgmkygvmdeyug")
    public suspend fun experimentalOptions(`value`: Output<Map<String, String>>) {
        this.experimentalOptions = value
    }

    /**
     * @param value Defines the type of insights that you want the service to generate. The allowed values are 'AudioInsightsOnly', 'VideoInsightsOnly', and 'AllInsights'. The default is AllInsights. If you set this to AllInsights and the input is audio only, then only audio insights are generated. Similarly if the input is video only, then only video insights are generated. It is recommended that you not use AudioInsightsOnly if you expect some of your inputs to be video only; or use VideoInsightsOnly if you expect some of your inputs to be audio only. Your Jobs in such conditions would error out.
     */
    @JvmName("yfsjsdhqvdsvhhav")
    public suspend fun insightsToExtract(`value`: Output<Either<String, InsightsType>>) {
        this.insightsToExtract = value
    }

    /**
     * @param value Determines the set of audio analysis operations to be performed. If unspecified, the Standard AudioAnalysisMode would be chosen.
     */
    @JvmName("csmsbjfxihetcskx")
    public suspend fun mode(`value`: Output<Either<String, AudioAnalysisMode>>) {
        this.mode = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.VideoAnalyzerPreset'.
     */
    @JvmName("dipqodoytwtditmd")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value The language for the audio payload in the input using the BCP-47 format of 'language tag-region' (e.g: 'en-US').  If you know the language of your content, it is recommended that you specify it. The language must be specified explicitly for AudioAnalysisMode::Basic, since automatic language detection is not included in basic mode. If the language isn't specified or set to null, automatic language detection will choose the first language detected and process with the selected language for the duration of the file. It does not currently support dynamically switching between languages after the first language is detected. The automatic detection works best with audio recordings with clearly discernable speech. If automatic detection fails to find the language, transcription would fallback to 'en-US'." The list of supported languages is available here: https://go.microsoft.com/fwlink/?linkid=2109463
     */
    @JvmName("iayaarnjvolvccae")
    public suspend fun audioLanguage(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audioLanguage = mapped
    }

    /**
     * @param value Dictionary containing key value pairs for parameters not exposed in the preset itself
     */
    @JvmName("hqrblshmwetmbtxu")
    public suspend fun experimentalOptions(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.experimentalOptions = mapped
    }

    /**
     * @param values Dictionary containing key value pairs for parameters not exposed in the preset itself
     */
    @JvmName("qadoenwdafyvsbsy")
    public fun experimentalOptions(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.experimentalOptions = mapped
    }

    /**
     * @param value Defines the type of insights that you want the service to generate. The allowed values are 'AudioInsightsOnly', 'VideoInsightsOnly', and 'AllInsights'. The default is AllInsights. If you set this to AllInsights and the input is audio only, then only audio insights are generated. Similarly if the input is video only, then only video insights are generated. It is recommended that you not use AudioInsightsOnly if you expect some of your inputs to be video only; or use VideoInsightsOnly if you expect some of your inputs to be audio only. Your Jobs in such conditions would error out.
     */
    @JvmName("nqxuojlydrfkrcbi")
    public suspend fun insightsToExtract(`value`: Either<String, InsightsType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.insightsToExtract = mapped
    }

    /**
     * @param value Defines the type of insights that you want the service to generate. The allowed values are 'AudioInsightsOnly', 'VideoInsightsOnly', and 'AllInsights'. The default is AllInsights. If you set this to AllInsights and the input is audio only, then only audio insights are generated. Similarly if the input is video only, then only video insights are generated. It is recommended that you not use AudioInsightsOnly if you expect some of your inputs to be video only; or use VideoInsightsOnly if you expect some of your inputs to be audio only. Your Jobs in such conditions would error out.
     */
    @JvmName("mbvdfviodhvethhg")
    public fun insightsToExtract(`value`: String) {
        val toBeMapped = Either.ofLeft<String, InsightsType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.insightsToExtract = mapped
    }

    /**
     * @param value Defines the type of insights that you want the service to generate. The allowed values are 'AudioInsightsOnly', 'VideoInsightsOnly', and 'AllInsights'. The default is AllInsights. If you set this to AllInsights and the input is audio only, then only audio insights are generated. Similarly if the input is video only, then only video insights are generated. It is recommended that you not use AudioInsightsOnly if you expect some of your inputs to be video only; or use VideoInsightsOnly if you expect some of your inputs to be audio only. Your Jobs in such conditions would error out.
     */
    @JvmName("qfdfceooqlxktbpu")
    public fun insightsToExtract(`value`: InsightsType) {
        val toBeMapped = Either.ofRight<String, InsightsType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.insightsToExtract = mapped
    }

    /**
     * @param value Determines the set of audio analysis operations to be performed. If unspecified, the Standard AudioAnalysisMode would be chosen.
     */
    @JvmName("qjwbthbckjgdyixn")
    public suspend fun mode(`value`: Either<String, AudioAnalysisMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value Determines the set of audio analysis operations to be performed. If unspecified, the Standard AudioAnalysisMode would be chosen.
     */
    @JvmName("pecrteluycaixxhe")
    public fun mode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AudioAnalysisMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value Determines the set of audio analysis operations to be performed. If unspecified, the Standard AudioAnalysisMode would be chosen.
     */
    @JvmName("lhdsufowwrydvsqo")
    public fun mode(`value`: AudioAnalysisMode) {
        val toBeMapped = Either.ofRight<String, AudioAnalysisMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.VideoAnalyzerPreset'.
     */
    @JvmName("airyafeshmcctmhv")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    internal fun build(): VideoAnalyzerPresetArgs = VideoAnalyzerPresetArgs(
        audioLanguage = audioLanguage,
        experimentalOptions = experimentalOptions,
        insightsToExtract = insightsToExtract,
        mode = mode,
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/VideoAnalyzerPresetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.VideoAnalyzerPresetArgs.builder
import com.pulumi.azurenative.media.kotlin.enums.AudioAnalysisMode
import com.pulumi.azurenative.media.kotlin.enums.InsightsType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A video analyzer preset that extracts insights (rich metadata) from both audio and video, and outputs a JSON format file.
 * @property audioLanguage The language for the audio payload in the input using the BCP-47 format of 'language tag-region' (e.g: 'en-US').  If you know the language of your content, it is recommended that you specify it. The language must be specified explicitly for AudioAnalysisMode::Basic, since automatic language detection is not included in basic mode. If the language isn't specified or set to null, automatic language detection will choose the first language detected and process with the selected language for the duration of the file. It does not currently support dynamically switching between languages after the first language is detected. The automatic detection works best with audio recordings with clearly discernable speech. If automatic detection fails to find the language, transcription would fallback to 'en-US'." The list of supported languages is available here: https://go.microsoft.com/fwlink/?linkid=2109463
 * @property experimentalOptions Dictionary containing key value pairs for parameters not exposed in the preset itself
 * @property insightsToExtract Defines the type of insights that you want the service to generate. The allowed values are 'AudioInsightsOnly', 'VideoInsightsOnly', and 'AllInsights'. The default is AllInsights. If you set this to AllInsights and the input is audio only, then only audio insights are generated. Similarly if the input is video only, then only video insights are generated. It is recommended that you not use AudioInsightsOnly if you expect some of your inputs to be video only; or use VideoInsightsOnly if you expect some of your inputs to be audio only. Your Jobs in such conditions would error out.
 * @property mode Determines the set of audio analysis operations to be performed. If unspecified, the Standard AudioAnalysisMode would be chosen.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.VideoAnalyzerPreset'.
 */
public data class VideoAnalyzerPresetArgs(
    public val audioLanguage: Output<String>? = null,
    public val experimentalOptions: Output<Map<String, String>>? = null,
    public val insightsToExtract: Output<Either<String, InsightsType>>? = null,
    public val mode: Output<Either<String, AudioAnalysisMode>>? = null,
    public val odataType: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.VideoAnalyzerPresetArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.VideoAnalyzerPresetArgs =
        com.pulumi.azurenative.media.inputs.VideoAnalyzerPresetArgs.builder()
            .audioLanguage(audioLanguage?.applyValue({ args0 -> args0 }))
            .experimentalOptions(
                experimentalOptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .insightsToExtract(
                insightsToExtract?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .mode(
                mode?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .odataType(odataType.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VideoAnalyzerPresetArgs].
 */
@PulumiTagMarker
public class VideoAnalyzerPresetArgsBuilder internal constructor() {
    private var audioLanguage: Output<String>? = null

    private var experimentalOptions: Output<Map<String, String>>? = null

    private var insightsToExtract: Output<Either<String, InsightsType>>? = null

    private var mode: Output<Either<String, AudioAnalysisMode>>? = null

    private var odataType: Output<String>? = null

    /**
     * @param value The language for the audio payload in the input using the BCP-47 format of 'language tag-region' (e.g: 'en-US').  If you know the language of your content, it is recommended that you specify it. The language must be specified explicitly for AudioAnalysisMode::Basic, since automatic language detection is not included in basic mode. If the language isn't specified or set to null, automatic language detection will choose the first language detected and process with the selected language for the duration of the file. It does not currently support dynamically switching between languages after the first language is detected. The automatic detection works best with audio recordings with clearly discernable speech. If automatic detection fails to find the language, transcription would fallback to 'en-US'." The list of supported languages is available here: https://go.microsoft.com/fwlink/?linkid=2109463
     */
    @JvmName("pdcvgibdxiyressf")
    public suspend fun audioLanguage(`value`: Output<String>) {
        this.audioLanguage = value
    }

    /**
     * @param value Dictionary containing key value pairs for parameters not exposed in the preset itself
     */
    @JvmName("njlmumkyssrikktb")
    public suspend fun experimentalOptions(`value`: Output<Map<String, String>>) {
        this.experimentalOptions = value
    }

    /**
     * @param value Defines the type of insights that you want the service to generate. The allowed values are 'AudioInsightsOnly', 'VideoInsightsOnly', and 'AllInsights'. The default is AllInsights. If you set this to AllInsights and the input is audio only, then only audio insights are generated. Similarly if the input is video only, then only video insights are generated. It is recommended that you not use AudioInsightsOnly if you expect some of your inputs to be video only; or use VideoInsightsOnly if you expect some of your inputs to be audio only. Your Jobs in such conditions would error out.
     */
    @JvmName("goskxgsiqfumjksk")
    public suspend fun insightsToExtract(`value`: Output<Either<String, InsightsType>>) {
        this.insightsToExtract = value
    }

    /**
     * @param value Determines the set of audio analysis operations to be performed. If unspecified, the Standard AudioAnalysisMode would be chosen.
     */
    @JvmName("yfjmwkwvojajmryq")
    public suspend fun mode(`value`: Output<Either<String, AudioAnalysisMode>>) {
        this.mode = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.VideoAnalyzerPreset'.
     */
    @JvmName("hfvowrooemexpwcp")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value The language for the audio payload in the input using the BCP-47 format of 'language tag-region' (e.g: 'en-US').  If you know the language of your content, it is recommended that you specify it. The language must be specified explicitly for AudioAnalysisMode::Basic, since automatic language detection is not included in basic mode. If the language isn't specified or set to null, automatic language detection will choose the first language detected and process with the selected language for the duration of the file. It does not currently support dynamically switching between languages after the first language is detected. The automatic detection works best with audio recordings with clearly discernable speech. If automatic detection fails to find the language, transcription would fallback to 'en-US'." The list of supported languages is available here: https://go.microsoft.com/fwlink/?linkid=2109463
     */
    @JvmName("einowrwrqrinrqvs")
    public suspend fun audioLanguage(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.audioLanguage = mapped
    }

    /**
     * @param value Dictionary containing key value pairs for parameters not exposed in the preset itself
     */
    @JvmName("hdayuodpucxdxsle")
    public suspend fun experimentalOptions(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.experimentalOptions = mapped
    }

    /**
     * @param values Dictionary containing key value pairs for parameters not exposed in the preset itself
     */
    @JvmName("alvulcpjsrgmypmm")
    public fun experimentalOptions(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.experimentalOptions = mapped
    }

    /**
     * @param value Defines the type of insights that you want the service to generate. The allowed values are 'AudioInsightsOnly', 'VideoInsightsOnly', and 'AllInsights'. The default is AllInsights. If you set this to AllInsights and the input is audio only, then only audio insights are generated. Similarly if the input is video only, then only video insights are generated. It is recommended that you not use AudioInsightsOnly if you expect some of your inputs to be video only; or use VideoInsightsOnly if you expect some of your inputs to be audio only. Your Jobs in such conditions would error out.
     */
    @JvmName("qkpjmswnhlbylqfp")
    public suspend fun insightsToExtract(`value`: Either<String, InsightsType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.insightsToExtract = mapped
    }

    /**
     * @param value Defines the type of insights that you want the service to generate. The allowed values are 'AudioInsightsOnly', 'VideoInsightsOnly', and 'AllInsights'. The default is AllInsights. If you set this to AllInsights and the input is audio only, then only audio insights are generated. Similarly if the input is video only, then only video insights are generated. It is recommended that you not use AudioInsightsOnly if you expect some of your inputs to be video only; or use VideoInsightsOnly if you expect some of your inputs to be audio only. Your Jobs in such conditions would error out.
     */
    @JvmName("pgcuphvdupiqjbqq")
    public fun insightsToExtract(`value`: String) {
        val toBeMapped = Either.ofLeft<String, InsightsType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.insightsToExtract = mapped
    }

    /**
     * @param value Defines the type of insights that you want the service to generate. The allowed values are 'AudioInsightsOnly', 'VideoInsightsOnly', and 'AllInsights'. The default is AllInsights. If you set this to AllInsights and the input is audio only, then only audio insights are generated. Similarly if the input is video only, then only video insights are generated. It is recommended that you not use AudioInsightsOnly if you expect some of your inputs to be video only; or use VideoInsightsOnly if you expect some of your inputs to be audio only. Your Jobs in such conditions would error out.
     */
    @JvmName("vxvpsfvdjitafcir")
    public fun insightsToExtract(`value`: InsightsType) {
        val toBeMapped = Either.ofRight<String, InsightsType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.insightsToExtract = mapped
    }

    /**
     * @param value Determines the set of audio analysis operations to be performed. If unspecified, the Standard AudioAnalysisMode would be chosen.
     */
    @JvmName("vsruvwwpxnvaohoq")
    public suspend fun mode(`value`: Either<String, AudioAnalysisMode>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value Determines the set of audio analysis operations to be performed. If unspecified, the Standard AudioAnalysisMode would be chosen.
     */
    @JvmName("ryhcywgxsoxxalcq")
    public fun mode(`value`: String) {
        val toBeMapped = Either.ofLeft<String, AudioAnalysisMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value Determines the set of audio analysis operations to be performed. If unspecified, the Standard AudioAnalysisMode would be chosen.
     */
    @JvmName("jcmjjwkypxdlskdw")
    public fun mode(`value`: AudioAnalysisMode) {
        val toBeMapped = Either.ofRight<String, AudioAnalysisMode>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.VideoAnalyzerPreset'.
     */
    @JvmName("cyscqvufyoxssfiv")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    internal fun build(): VideoAnalyzerPresetArgs = VideoAnalyzerPresetArgs(
        audioLanguage = audioLanguage,
        experimentalOptions = experimentalOptions,
        insightsToExtract = insightsToExtract,
        mode = mode,
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
    )
}
